@@ -1,6 +1,8 @@
 package action
 
 import (
+	"context"
+
 	"github.com/k0sproject/k0sctl/phase"
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1/cluster"
 )
@@ -15,7 +17,7 @@ type Kubeconfig struct {
 	Kubeconfig string
 }
 
-func (k *Kubeconfig) Run() error {
+func (k *Kubeconfig) Run(ctx context.Context) error {
 	// Change so that the internal config has only single controller host as we
 	// do not need to connect to all nodes
 	k.Manager.Config.Spec.Hosts = cluster.Hosts{k.Manager.Config.Spec.K0sLeader()}
@@ -27,5 +29,5 @@ func (k *Kubeconfig) Run() error {
 		&phase.Disconnect{},
 	)
 
-	return k.Manager.Run()
+	return k.Manager.Run(ctx)
 }
