@@ -15,16 +15,18 @@ var configEditCommand = &cli.Command{
 		debugFlag,
 		traceFlag,
 		redactFlag,
+		timeoutFlag,
 	},
 	Before: actions(initLogging, initConfig),
+	After:  actions(cancelTimeout),
 	Action: func(ctx *cli.Context) error {
 		configEditAction := action.ConfigEdit{
-			Config: ctx.Context.Value(ctxConfigKey{}).(*v1beta1.Cluster),
+			Config: ctx.Context.Value(ctxConfigsKey{}).(*v1beta1.Cluster),
 			Stdout: ctx.App.Writer,
 			Stderr: ctx.App.ErrWriter,
 			Stdin:  ctx.App.Reader,
 		}
 
-		return configEditAction.Run()
+		return configEditAction.Run(ctx.Context)
 	},
 }
