@@ -2,7 +2,6 @@ package cmd
 
 import (
 	"github.com/k0sproject/k0sctl/action"
-	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1"
 
 	"github.com/urfave/cli/v2"
 )
@@ -15,6 +14,7 @@ var configStatusCommand = &cli.Command{
 		debugFlag,
 		traceFlag,
 		redactFlag,
+		timeoutFlag,
 		&cli.StringFlag{
 			Name:    "output",
 			Usage:   "kubectl output formatting",
@@ -22,13 +22,19 @@ var configStatusCommand = &cli.Command{
 		},
 	},
 	Before: actions(initLogging, initConfig),
+	After:  actions(cancelTimeout),
 	Action: func(ctx *cli.Context) error {
+		cfg, err := readConfig(ctx)
+		if err != nil {
+			return err
+		}
+
 		configStatusAction := action.ConfigStatus{
-			Config: ctx.Context.Value(ctxConfigKey{}).(*v1beta1.Cluster),
+			Config: cfg,
 			Format: ctx.String("output"),
 			Writer: ctx.App.Writer,
 		}
 
-		return configStatusAction.Run()
+		return configStatusAction.Run(ctx.Context)
 	},
 }
