@@ -23,9 +23,9 @@ func (p *Connect) Title() string {
 }
 
 // Run the phase
-func (p *Connect) Run() error {
-	return p.parallelDo(p.Config.Spec.Hosts, func(h *cluster.Host) error {
-		return retry.Timeout(context.TODO(), 10*time.Minute, func(_ context.Context) error {
+func (p *Connect) Run(ctx context.Context) error {
+	return p.parallelDo(ctx, p.Config.Spec.Hosts, func(ctx context.Context, h *cluster.Host) error {
+		return retry.AdaptiveTimeout(ctx, 10*time.Minute, func(_ context.Context) error {
 			if err := h.Connect(); err != nil {
 				if errors.Is(err, rig.ErrCantConnect) || strings.Contains(err.Error(), "host key mismatch") {
 					return errors.Join(retry.ErrAbort, err)
