@@ -1,6 +1,7 @@
 package phase
 
 import (
+	"context"
 	"strings"
 
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1/cluster"
@@ -26,8 +27,8 @@ func (p *DetectOS) Title() string {
 }
 
 // Run the phase
-func (p *DetectOS) Run() error {
-	return p.parallelDo(p.Config.Spec.Hosts, func(h *cluster.Host) error {
+func (p *DetectOS) Run(ctx context.Context) error {
+	return p.parallelDo(ctx, p.Config.Spec.Hosts, func(_ context.Context, h *cluster.Host) error {
 		if h.OSIDOverride != "" {
 			log.Infof("%s: OS ID has been manually set to %s", h, h.OSIDOverride)
 		}
