@@ -1,6 +1,7 @@
 package phase
 
 import (
+	"context"
 	"strings"
 	"testing"
 
@@ -50,14 +51,14 @@ func TestGetKubeconfig(t *testing.T) {
 	readKubeconfig = fakeReader
 
 	p := GetKubeconfig{GenericPhase: GenericPhase{Config: cfg}}
-	require.NoError(t, p.Run())
+	require.NoError(t, p.Run(context.Background()))
 	conf, err := clientcmd.Load([]byte(cfg.Metadata.Kubeconfig))
 	require.NoError(t, err)
 	require.Equal(t, "https://10.0.0.1:6443", conf.Clusters["k0s"].Server)
 
 	cfg.Spec.Hosts[0].Connection.SSH.Address = "abcd:efgh:ijkl:mnop"
 	p.APIAddress = ""
-	require.NoError(t, p.Run())
+	require.NoError(t, p.Run(context.Background()))
 	conf, err = clientcmd.Load([]byte(cfg.Metadata.Kubeconfig))
 	require.NoError(t, err)
 	require.Equal(t, "https://[abcd:efgh:ijkl:mnop]:6443", conf.Clusters["k0s"].Server)
