@@ -15,7 +15,7 @@ import (
 	log "github.com/sirupsen/logrus"
 )
 
-var iptablesEmbeddedSince = version.MustConstraint(">= v1.22.1+k0s.0")
+var iptablesEmbeddedSince = version.MustParse("v1.22.1+k0s.0")
 
 // PrepareHosts installs required packages and so on on the hosts.
 type PrepareHosts struct {
@@ -28,8 +28,8 @@ func (p *PrepareHosts) Title() string {
 }
 
 // Run the phase
-func (p *PrepareHosts) Run() error {
-	return p.parallelDo(p.Config.Spec.Hosts, p.prepareHost)
+func (p *PrepareHosts) Run(ctx context.Context) error {
+	return p.parallelDo(ctx, p.Config.Spec.Hosts, p.prepareHost)
 }
 
 type prepare interface {
@@ -38,7 +38,7 @@ type prepare interface {
 
 // updateEnvironment updates the environment variables on the host and reconnects to
 // it if necessary.
-func (p *PrepareHosts) updateEnvironment(h *cluster.Host) error {
+func (p *PrepareHosts) updateEnvironment(ctx context.Context, h *cluster.Host) error {
 	if err := h.Configurer.UpdateEnvironment(h, h.Environment); err != nil {
 		return err
 	}
@@ -53,7 +53,7 @@ func (p *PrepareHosts) updateEnvironment(h *cluster.Host) error {
 	// server configuration (sshd only accepts LC_* variables by default).
 	log.Infof("%s: reconnecting to apply new environment", h)
 	h.Disconnect()
-	return retry.Timeout(context.TODO(), 10*time.Minute, func(_ context.Context) error {
+	return retry.AdaptiveTimeout(ctx, 10*time.Minute, func(_ context.Context) error {
 		if err := h.Connect(); err != nil {
 			if errors.Is(err, rig.ErrCantConnect) || strings.Contains(err.Error(), "host key mismatch") {
 				return errors.Join(retry.ErrAbort, err)
@@ -64,7 +64,7 @@ func (p *PrepareHosts) updateEnvironment(h *cluster.Host) error {
 	})
 }
 
-func (p *PrepareHosts) prepareHost(h *cluster.Host) error {
+func (p *PrepareHosts) prepareHost(ctx context.Context, h *cluster.Host) error {
 	if c, ok := h.Configurer.(prepare); ok {
 		if err := c.Prepare(h); err != nil {
 			return err
@@ -73,7 +73,7 @@ func (p *PrepareHosts) prepareHost(h *cluster.Host) error {
 
 	if len(h.Environment) > 0 {
 		log.Infof("%s: updating environment", h)
-		if err := p.updateEnvironment(h); err != nil {
+		if err := p.updateEnvironment(ctx, h); err != nil {
 			return fmt.Errorf("failed to updated environment: %w", err)
 		}
 	}
@@ -85,7 +85,7 @@ func (p *PrepareHosts) prepareHost(h *cluster.Host) error {
 	}
 
 	// iptables is only required for very old versions of k0s
-	if p.Config.Spec.K0s.Version != nil && !iptablesEmbeddedSince.Check(p.Config.Spec.K0s.Version) && h.NeedIPTables() { //nolint:staticcheck
+	if p.Config.Spec.K0s.Version != nil && !p.Config.Spec.K0s.Version.GreaterThanOrEqual(iptablesEmbeddedSince) && h.NeedIPTables() { //nolint:staticcheck
 		pkgs = append(pkgs, "iptables")
 	}
 
