@@ -1,6 +1,7 @@
 package phase
 
 import (
+	"context"
 	"fmt"
 	"path"
 
@@ -36,7 +37,7 @@ func (p *Restore) Prepare(config *v1beta1.Cluster) error {
 	}
 
 	// defined in backup.go
-	if !backupSinceVersion.Check(p.Config.Spec.K0s.Version) {
+	if p.Config.Spec.K0s.Version.LessThan(backupSinceVersion) {
 		return fmt.Errorf("the version of k0s on the host does not support restoring backups")
 	}
 
@@ -48,7 +49,7 @@ func (p *Restore) Prepare(config *v1beta1.Cluster) error {
 }
 
 // Run the phase
-func (p *Restore) Run() error {
+func (p *Restore) Run(_ context.Context) error {
 	// Push the backup file to controller
 	h := p.leader
 	tmpDir, err := h.Configurer.TempDir(h)
